<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'musicsong_pro_about_section', array(
	'title'             => esc_html__( 'About Us','musicsong-pro' ),
	'description'       => esc_html__( 'About Section options.', 'musicsong-pro' ),
	'panel'             => 'musicsong_pro_front_page_panel',
) );

// About content enable control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'musicsong_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Musicsong_Pro_Switch_Control( $wp_customize, 'musicsong_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_about_section',
	'on_off_label' 		=> musicsong_pro_switch_options(),
) ) );

// about subtitle setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[about_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[about_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_about_section',
	'active_callback' 	=> 'musicsong_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[about_subtitle]', array(
		'selector'            => '#popular-artists .section-header p.section-subtitle',
		'settings'            => 'musicsong_pro_theme_options[about_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_about_subtitle_partial',
    ) );
}

// Service column type control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[about_column]', array(
	'default'          	=> $options['about_column'],
	'sanitize_callback' => 'musicsong_pro_sanitize_select',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[about_column]', array(
	'label'             => esc_html__( 'Column', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'musicsong_pro_is_about_section_enable',
	'choices'			=> array( 
		'col-1' 		=> esc_html__( 'One Column', 'musicsong-pro' ),
		'col-2' 		=> esc_html__( 'Two Column', 'musicsong-pro' ),
	),
) );

// About content type control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'musicsong_pro_sanitize_select',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'musicsong_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'musicsong-pro' ),
		'post' 		=> esc_html__( 'Post', 'musicsong-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'musicsong-pro' ),
	),
) );

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'musicsong_pro_sanitize_page',
) );

$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_about_section',
	'choices'			=> musicsong_pro_page_choices(),
	'active_callback'	=> 'musicsong_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'musicsong_pro_sanitize_page',
) );

$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_about_section',
	'choices'			=> musicsong_pro_post_choices(),
	'active_callback'	=> 'musicsong_pro_is_about_section_content_post_enable',
) ) );

// about title setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[about_title]', array(
	'label'           	=> esc_html__( 'Title', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_about_section',
	'active_callback' 	=> 'musicsong_pro_is_about_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[about_title]', array(
		'selector'            => '#popular-artists .entry-container .section-header h2.section-title',
		'settings'            => 'musicsong_pro_theme_options[about_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_about_title_partial',
    ) );
}

// about description setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['about_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[about_description]', array(
	'label'           	=> esc_html__( 'Description', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_about_section',
	'active_callback' 	=> 'musicsong_pro_is_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[about_description]', array(
		'selector'            => '#popular-artists .entry-container .entry-content p',
		'settings'            => 'musicsong_pro_theme_options[about_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_about_description_partial',
    ) );
}

// about image setting and control.
$wp_customize->add_setting( 'musicsong_pro_theme_options[about_image]', array(
	'sanitize_callback' => 'musicsong_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'musicsong_pro_theme_options[about_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'musicsong-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'musicsong-pro' ), 512, 520 ),
		'section'     		=> 'musicsong_pro_about_section',
		'active_callback'	=> 'musicsong_pro_is_about_section_content_custom_enable',
) ) );

// about btn title setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_about_section',
	'active_callback' 	=> 'musicsong_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[about_btn_title]', array(
		'selector'            => '#popular-artists .read-more a',
		'settings'            => 'musicsong_pro_theme_options[about_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_about_btn_title_partial',
    ) );
}

// about btn link setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[about_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[about_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_about_section',
	'active_callback' 	=> 'musicsong_pro_is_about_section_content_custom_enable',
	'type'				=> 'url',
) );

// playlist posts drop down chooser control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[about_playlist]', array(
	'sanitize_callback' => 'musicsong_pro_sanitize_array_int',
) );

$wp_customize->add_control( new Musicsong_Pro_Multiple_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[about_playlist]', array(
	'label'             => esc_html__( 'Select Multiple Audios', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_about_section',
	'choices'			=> musicsong_pro_audio_choices(),
	'active_callback'	=> 'musicsong_pro_is_about_section_enable',
) ) );
