<?php
/**
 * Artists Section options
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */

// Add Artists section
$wp_customize->add_section( 'musicsong_pro_artists_section', array(
	'title'             => esc_html__( 'Artists','musicsong-pro' ),
	'description'       => esc_html__( 'Artists Section options.', 'musicsong-pro' ),
	'panel'             => 'musicsong_pro_front_page_panel',
) );

// Artists content enable control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[artists_section_enable]', array(
	'default'			=> 	$options['artists_section_enable'],
	'sanitize_callback' => 'musicsong_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Musicsong_Pro_Switch_Control( $wp_customize, 'musicsong_pro_theme_options[artists_section_enable]', array(
	'label'             => esc_html__( 'Artists Section Enable', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_artists_section',
	'on_off_label' 		=> musicsong_pro_switch_options(),
) ) );

// artists title setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[artists_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['artists_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[artists_title]', array(
	'label'           	=> esc_html__( 'Title', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_artists_section',
	'active_callback' 	=> 'musicsong_pro_is_artists_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[artists_title]', array(
		'selector'            => '#team-members .section-header h2.section-title',
		'settings'            => 'musicsong_pro_theme_options[artists_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_artists_title_partial',
    ) );
}

// artists subtitle setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[artists_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['artists_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[artists_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_artists_section',
	'active_callback' 	=> 'musicsong_pro_is_artists_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[artists_subtitle]', array(
		'selector'            => '#team-members .section-header p.section-subtitle',
		'settings'            => 'musicsong_pro_theme_options[artists_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_artists_subtitle_partial',
    ) );
}

// Artists column control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[artists_column]', array(
	'default'          	=> $options['artists_column'],
	'sanitize_callback' => 'musicsong_pro_sanitize_select',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[artists_column]', array(
	'label'             => esc_html__( 'Column', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_artists_section',
	'type'				=> 'select',
	'active_callback' 	=> 'musicsong_pro_is_artists_section_enable',
	'choices'			=> array( 
		'col-1' 	=> esc_html__( 'One Column', 'musicsong-pro' ),
		'col-2' 	=> esc_html__( 'Two Column', 'musicsong-pro' ),
		'col-3' 	=> esc_html__( 'Three Column', 'musicsong-pro' ),
		'col-4' 	=> esc_html__( 'Four Column', 'musicsong-pro' ),
	),
) );

// Artists content type control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[artists_content_type]', array(
	'default'          	=> $options['artists_content_type'],
	'sanitize_callback' => 'musicsong_pro_sanitize_select',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[artists_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_artists_section',
	'type'				=> 'select',
	'active_callback' 	=> 'musicsong_pro_is_artists_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'musicsong-pro' ),
		'post' 		=> esc_html__( 'Post', 'musicsong-pro' ),
		'category' 	=> esc_html__( 'Category', 'musicsong-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'musicsong-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[artists_count]', array(
	'default'          	=> $options['artists_count'],
	'sanitize_callback' => 'musicsong_pro_sanitize_number_range',
	'validate_callback' => 'musicsong_pro_validate_artists_count',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[artists_count]', array(
	'label'             => esc_html__( 'Number of Artists', 'musicsong-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_artists_section',
	'active_callback'   => 'musicsong_pro_is_artists_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'musicsong_pro_theme_options[artists_content_category]', array(
	'sanitize_callback' => 'musicsong_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Musicsong_Pro_Dropdown_Taxonomies_Control( $wp_customize,'musicsong_pro_theme_options[artists_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'musicsong-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_artists_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'musicsong_pro_is_artists_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['artists_count']; $i++ ) :
	// artists pages drop down chooser control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[artists_content_page_' . $i . ']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[artists_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'musicsong-pro' ), $i ),
		'section'           => 'musicsong_pro_artists_section',
		'choices'			=> musicsong_pro_page_choices(),
		'active_callback'	=> 'musicsong_pro_is_artists_section_content_page_enable',
	) ) );

	// artists posts drop down chooser control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[artists_content_post_' . $i . ']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[artists_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'musicsong-pro' ), $i ),
		'section'           => 'musicsong_pro_artists_section',
		'choices'			=> musicsong_pro_post_choices(),
		'active_callback'	=> 'musicsong_pro_is_artists_section_content_post_enable',
	) ) );

	// artists title setting and control
	$wp_customize->add_setting( 'musicsong_pro_theme_options[artists_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'musicsong_pro_theme_options[artists_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'musicsong-pro' ), $i ),
		'section'        	=> 'musicsong_pro_artists_section',
		'active_callback' 	=> 'musicsong_pro_is_artists_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// artists position setting and control
	$wp_customize->add_setting( 'musicsong_pro_theme_options[artists_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'musicsong_pro_theme_options[artists_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Position %d', 'musicsong-pro' ), $i ),
		'section'        	=> 'musicsong_pro_artists_section',
		'active_callback' 	=> 'musicsong_pro_is_artists_section_content_position_enable',
		'type'				=> 'text',
	) );

	// artists image setting and control.
	$wp_customize->add_setting( 'musicsong_pro_theme_options[artists_image_' . $i . ']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'musicsong_pro_theme_options[artists_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'musicsong-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'musicsong-pro' ), 200, 200 ),
			'section'     		=> 'musicsong_pro_artists_section',
			'active_callback'	=> 'musicsong_pro_is_artists_section_content_custom_enable',
	) ) );

	// artists position setting and control
	$wp_customize->add_setting( 'musicsong_pro_theme_options[artists_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'musicsong_pro_theme_options[artists_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'URL Link %d', 'musicsong-pro' ), $i ),
		'section'        	=> 'musicsong_pro_artists_section',
		'active_callback' 	=> 'musicsong_pro_is_artists_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// artists social links setting and control
	$wp_customize->add_setting( 'musicsong_pro_theme_options[artists_social_'. $i .']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_links'
	) );

	$wp_customize->add_control( new Musicsong_Pro_Multi_Input_Custom_Control( $wp_customize, 'musicsong_pro_theme_options[artists_social_'. $i .']',
		array(
			'label'       	  => sprintf( esc_html__( 'Social Links %d', 'musicsong-pro' ), $i ),
			'button_text'     => sprintf( esc_html__( 'Add More Social Link', 'musicsong-pro' ), $i ),
			'section'         => 'musicsong_pro_artists_section',
			'active_callback' => 'musicsong_pro_is_artists_section_content_seperator_enable',
			'type'			  => 'multi-input'
	) ) );

	// artists hr setting and control
	$wp_customize->add_setting( 'musicsong_pro_theme_options[artists_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Musicsong_Pro_Customize_Horizontal_Line( $wp_customize, 'musicsong_pro_theme_options[artists_hr_'. $i .']',
		array(
			'section'         => 'musicsong_pro_artists_section',
			'active_callback' => 'musicsong_pro_is_artists_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// artists btn title setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[artists_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['artists_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[artists_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_artists_section',
	'active_callback' 	=> 'musicsong_pro_is_artists_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[artists_btn_title]', array(
		'selector'            => '#team-members .read-more a.btn',
		'settings'            => 'musicsong_pro_theme_options[artists_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_artists_title_partial',
    ) );
}

// artists btn link setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[artists_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[artists_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_artists_section',
	'active_callback' 	=> 'musicsong_pro_is_artists_section_enable',
	'type'				=> 'url',
) );
