<?php
/**
 * Latest Release Section options
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */

// Add Latest Release section
$wp_customize->add_section( 'musicsong_pro_latest_release_section', array(
	'title'             => esc_html__( 'Latest Release','musicsong-pro' ),
	'description'       => esc_html__( 'Latest Release Section options.', 'musicsong-pro' ),
	'panel'             => 'musicsong_pro_front_page_panel',
) );

// Latest Release content enable control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[latest_release_section_enable]', array(
	'default'			=> 	$options['latest_release_section_enable'],
	'sanitize_callback' => 'musicsong_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Musicsong_Pro_Switch_Control( $wp_customize, 'musicsong_pro_theme_options[latest_release_section_enable]', array(
	'label'             => esc_html__( 'Latest Release Section Enable', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_latest_release_section',
	'on_off_label' 		=> musicsong_pro_switch_options(),
) ) );

// latest_release title setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[latest_release_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_release_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[latest_release_title]', array(
	'label'           	=> esc_html__( 'Title', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_latest_release_section',
	'active_callback' 	=> 'musicsong_pro_is_latest_release_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[latest_release_title]', array(
		'selector'            => '#latest-albums .section-header h2.section-title',
		'settings'            => 'musicsong_pro_theme_options[latest_release_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_latest_release_title_partial',
    ) );
}

// latest_release subtitle setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[latest_release_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_release_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[latest_release_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_latest_release_section',
	'active_callback' 	=> 'musicsong_pro_is_latest_release_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[latest_release_subtitle]', array(
		'selector'            => '#latest-albums .section-header p.section-subtitle',
		'settings'            => 'musicsong_pro_theme_options[latest_release_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_latest_release_subtitle_partial',
    ) );
}

// latest_release description setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[latest_release_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['latest_release_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[latest_release_description]', array(
	'label'           	=> esc_html__( 'Description', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_latest_release_section',
	'active_callback' 	=> 'musicsong_pro_is_latest_release_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[latest_release_description]', array(
		'selector'            => '#latest-albums .section-content p',
		'settings'            => 'musicsong_pro_theme_options[latest_release_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_latest_release_description_partial',
    ) );
}

// latest_release btn_title setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[latest_release_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_release_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[latest_release_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_latest_release_section',
	'active_callback' 	=> 'musicsong_pro_is_latest_release_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[latest_release_btn_title]', array(
		'selector'            => '#latest-albums .read-more a',
		'settings'            => 'musicsong_pro_theme_options[latest_release_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_latest_release_btn_title_partial',
    ) );
}

// latest_release btn_url setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[latest_release_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[latest_release_btn_url]', array(
	'label'           	=> esc_html__( 'Button Url', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_latest_release_section',
	'active_callback' 	=> 'musicsong_pro_is_latest_release_section_enable',
	'type'				=> 'url',
) );

// latest_release posts drop down chooser control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[latest_release_hr]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Musicsong_Pro_Customize_Horizontal_Line( $wp_customize, 'musicsong_pro_theme_options[latest_release_hr]', array(
	'type'				=> 'hr',
	'section'           => 'musicsong_pro_latest_release_section',
	'active_callback'	=> 'musicsong_pro_is_latest_release_section_enable',
) ) );

// Latest Release content type control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[latest_release_content_type]', array(
	'default'          	=> $options['latest_release_content_type'],
	'sanitize_callback' => 'musicsong_pro_sanitize_select',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[latest_release_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_latest_release_section',
	'type'				=> 'select',
	'active_callback' 	=> 'musicsong_pro_is_latest_release_section_enable',
	'choices'			=> musicsong_pro_latest_release_content_type(),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'musicsong_pro_theme_options[latest_release_content_category]', array(
	'sanitize_callback' => 'musicsong_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Musicsong_Pro_Dropdown_Taxonomies_Control( $wp_customize,'musicsong_pro_theme_options[latest_release_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'musicsong-pro' ),
	'description'      	=> esc_html__( 'Note: Latest three posts will be shown from selected category', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_latest_release_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'musicsong_pro_is_latest_release_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'musicsong_pro_theme_options[latest_release_content_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Musicsong_Pro_Dropdown_Taxonomies_Control( $wp_customize,'musicsong_pro_theme_options[latest_release_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'musicsong-pro' ),
	'description'      	=> esc_html__( 'Note: Latest three posts will be shown from selected category', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_latest_release_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'musicsong_pro_is_latest_release_section_content_product_category_enable'
) ) );

for ( $i = 1; $i <= 3; $i++ ) :

	// latest_release posts drop down chooser control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[latest_release_content_page_' . $i . ']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[latest_release_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'musicsong-pro' ), $i ),
		'section'           => 'musicsong_pro_latest_release_section',
		'choices'			=> musicsong_pro_page_choices(),
		'active_callback'	=> 'musicsong_pro_is_latest_release_section_content_page_enable',
	) ) );

	// latest_release posts drop down chooser control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[latest_release_content_post_' . $i . ']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[latest_release_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'musicsong-pro' ), $i ),
		'section'           => 'musicsong_pro_latest_release_section',
		'choices'			=> musicsong_pro_post_choices(),
		'active_callback'	=> 'musicsong_pro_is_latest_release_section_content_post_enable',
	) ) );

	// latest_release posts drop down chooser control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[latest_release_content_product_' . $i . ']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[latest_release_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'musicsong-pro' ), $i ),
		'section'           => 'musicsong_pro_latest_release_section',
		'choices'			=> musicsong_pro_product_choices(),
		'active_callback'	=> 'musicsong_pro_is_latest_release_section_content_product_enable',
	) ) );

	// latest_release subtitle setting and control
	$wp_customize->add_setting( 'musicsong_pro_theme_options[latest_release_post_subtitle_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'musicsong_pro_theme_options[latest_release_post_subtitle_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Post Sub Title %d', 'musicsong-pro' ), $i ),
		'section'        	=> 'musicsong_pro_latest_release_section',
		'active_callback' 	=> 'musicsong_pro_is_latest_release_section_enable',
		'type'				=> 'text',
	) );

endfor;
