<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'musicsong_pro_service_section', array(
	'title'             => esc_html__( 'Services','musicsong-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'musicsong-pro' ),
	'panel'             => 'musicsong_pro_front_page_panel',
) );

// Service content enable control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'musicsong_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Musicsong_Pro_Switch_Control( $wp_customize, 'musicsong_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_service_section',
	'on_off_label' 		=> musicsong_pro_switch_options(),
) ) );

// Service column type control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[service_column]', array(
	'default'          	=> $options['service_column'],
	'sanitize_callback' => 'musicsong_pro_sanitize_select',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[service_column]', array(
	'label'             => esc_html__( 'Column', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'musicsong_pro_is_service_section_enable',
	'choices'			=> array( 
		'col-2' 		=> esc_html__( 'Two Column', 'musicsong-pro' ),
		'col-3' 		=> esc_html__( 'Three Column', 'musicsong-pro' ),
	),
) );

// Service content type control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'musicsong_pro_sanitize_select',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'musicsong_pro_is_service_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'musicsong-pro' ),
		'post' 		=> esc_html__( 'Post', 'musicsong-pro' ),
		'category' 	=> esc_html__( 'Category', 'musicsong-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'musicsong_pro_sanitize_number_range',
	'validate_callback' => 'musicsong_pro_validate_service_count',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of Services', 'musicsong-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_service_section',
	'active_callback'   => 'musicsong_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['service_count']; $i++ ) :

	// service note control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Icon_Picker( $wp_customize, 'musicsong_pro_theme_options[service_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'musicsong-pro' ), $i ),
		'section'           => 'musicsong_pro_service_section',
		'active_callback'	=> 'musicsong_pro_is_service_section_enable',
	) ) );

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'musicsong-pro' ), $i ),
		'section'           => 'musicsong_pro_service_section',
		'choices'			=> musicsong_pro_page_choices(),
		'active_callback'	=> 'musicsong_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'musicsong-pro' ), $i ),
		'section'           => 'musicsong_pro_service_section',
		'choices'			=> musicsong_pro_post_choices(),
		'active_callback'	=> 'musicsong_pro_is_service_section_content_post_enable',
	) ) );

	// service hr setting and control
	$wp_customize->add_setting( 'musicsong_pro_theme_options[service_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Musicsong_Pro_Customize_Horizontal_Line( $wp_customize, 'musicsong_pro_theme_options[service_hr_'. $i .']',
		array(
			'section'         => 'musicsong_pro_service_section',
			'active_callback' => 'musicsong_pro_is_service_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'musicsong_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'musicsong_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Musicsong_Pro_Dropdown_Taxonomies_Control( $wp_customize,'musicsong_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'musicsong-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'musicsong_pro_is_service_section_content_category_enable'
) ) );
