<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */
if ( ! function_exists( 'musicsong_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Musicsong Pro 1.0.0
    */
    function musicsong_pro_add_about_section() {
    	$options = musicsong_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'musicsong_pro_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'musicsong_pro_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        musicsong_pro_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'musicsong_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Musicsong Pro 1.0.0
    * @param array $input about section details.
    */
    function musicsong_pro_get_about_section_details( $input ) {
        $options = musicsong_pro_get_theme_options();

        // Content type.
        $about_content_type  = $options['about_content_type'];
        
        $content = array();
        switch ( $about_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['about_title'] ) ? $options['about_title'] : '';
                $custom['excerpt']      = ! empty( $options['about_description'] ) ? $options['about_description'] : '';
                $custom['image']        = ! empty( $options['about_image'] ) ? $options['about_image'] : '';
                $custom['url']          = ! empty( $options['about_btn_link'] ) ? $options['about_btn_link'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['about_content_page'] ) ? $options['about_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['about_content_post'] ) ? $options['about_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $about_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = musicsong_pro_trim_content( 25 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'musicsong_pro_filter_about_section_details', 'musicsong_pro_get_about_section_details' );


if ( ! function_exists( 'musicsong_pro_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Musicsong Pro 1.0.0
   *
   */
   function musicsong_pro_render_about_section( $content_details = array() ) {
        $options = musicsong_pro_get_theme_options();
        $column = ! empty( $options['about_column'] ) ? $options['about_column'] : 'col-2';
        $readmore = ! empty( $options['about_btn_title'] ) ? $options['about_btn_title'] : esc_html__( 'Read More', 'musicsong-pro' );
        $playlist = ! empty( $options['about_playlist'] ) ? $options['about_playlist'] : array();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="popular-artists" class="relative page-section">
            <div class="wrapper">
                <div class="clear <?php echo esc_attr( $column ); ?>">
                    <?php foreach ( $content_details as $content ) : ?>
                        <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->
                            <?php endif; ?>

                            <div class="entry-container">
                                <?php if ( ! empty( $content['title'] ) || ! empty( $options['about_subtitle'] ) ) : ?>
                                    <div class="section-header">
                                        <?php if ( ! empty( $content['title'] ) ) : ?>
                                            <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                        <?php endif; 

                                        if ( ! empty( $options['about_subtitle'] ) ) : ?>
                                            <p class="section-subtitle"><?php echo esc_html( $options['about_subtitle'] ); ?></p>
                                        <?php endif; ?>
                                    </div><!-- .section-header -->
                                <?php endif; 

                                if ( ! empty( $content['excerpt'] ) ) : ?>
                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                <?php endif;

                                if ( ! empty( $content['url'] ) ) : ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-fill">   <?php echo esc_html( $readmore ); ?>
                                        </a>
                                    </div><!-- .read-more -->
                                <?php endif; ?>
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach; 

                    if ( ! empty( $playlist ) ) :
                        $playlist = implode(',', $playlist); ?>

                        <div class="playlist">
                            <?php 
                                $playlist_shortcode = '[playlist type="audio" ids="' . $playlist . '" style="light"]';
                                echo do_shortcode( wp_kses_post( $playlist_shortcode ) );  
                            ?>
                        </div><!-- .playlist -->
                    <?php endif; ?>
                </div><!-- .section-content-wrapper -->
            </div><!-- .wrapper -->
        </div><!-- #popular-artists -->

    <?php }
endif;
