<?php
/**
 * Product section
 *
 * This is the template for the content of product section
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */
if ( ! function_exists( 'musicsong_pro_add_product_section' ) ) :
    /**
    * Add product section
    *
    *@since Musicsong Pro 1.0.0
    */
    function musicsong_pro_add_product_section() {
    	$options = musicsong_pro_get_theme_options();
        // Check if product is enabled on frontpage
        $product_enable = apply_filters( 'musicsong_pro_section_status', true, 'product_section_enable' );

        if ( ( true !== $product_enable) || ! class_exists( 'WooCommerce' ) ) {
            return false;
        }

        // Render product section now.
        musicsong_pro_render_product_section();
    }
endif;

if ( ! function_exists( 'musicsong_pro_render_product_section' ) ) :
  /**
   * Start product section
   *
   * @return string product content
   * @since Musicsong Pro 1.0.0
   *
   */
   function musicsong_pro_render_product_section() {
        $options = musicsong_pro_get_theme_options();

        if ( 'product' == $options['product_content_type'] ) :
            $product = array();
            for ( $i = 1; $i <= $options['product_count']; $i++ ) :
                if ( ! empty( $options['product_content_product_' . $i] ) )
                    $product[$i] = absint( $options['product_content_product_' . $i] );
            endfor;
        elseif ( 'product-category' == $options['product_content_type'] ) :
            $product = ! empty( $options['product_content_product_category'] ) ? $options['product_content_product_category'] : '';
        endif;
        
        if ( in_array( $options['product_content_type'], array( 'product', 'product-category' ) ) ) :
            $product = is_array( $product ) ? implode(',', $product) : $product;
        endif;
        ?>

        <div id="latest-products" class="relative page-section">
            <div class="wrapper">
                <?php if ( ! empty( $options['product_title'] ) || ! empty( $options['product_subtitle'] ) ) : ?>
                    <div class="section-header">
                        <?php if ( ! empty( $options['product_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['product_title'] ); ?></h2>
                        <?php endif; 

                        if ( ! empty( $options['product_subtitle'] ) ) : ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['product_subtitle'] ); ?></p>
                        <?php endif; ?>
                    </div><!-- .section-header -->
                <?php endif; ?>

                <div class="section-content clear">
                    <?php 
                        $product_shortcode = '[products limit="' . absint( $options['product_count'] ) . '" columns="4"';
                        if ( 'product' == $options['product_content_type'] ) :
                            $product_shortcode .= ' ids="' . $product . '"';
                        elseif ( 'product-category' == $options['product_content_type'] ) :
                            $product = get_term_by( 'id', $product, 'product_cat' );
                            $product_shortcode .= ' category="' . $product->slug . '"';
                        elseif ( 'recent' == $options['product_content_type'] ) :
                            $product_shortcode .= ' orderby="id" order="DESC" visibility="visible"';
                        elseif ( 'featured' == $options['product_content_type'] ) :
                            $product_shortcode .= ' visibility="featured"';
                        elseif ( 'best-selling' == $options['product_content_type'] ) :
                            $product_shortcode .= ' best_selling="true"';
                        endif;
                        $product_shortcode .= ']';
                        echo do_shortcode( wp_kses_post( $product_shortcode ) );  
                    ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #product-section -->

    <?php }
endif;