<?php
/**
 * Subscription section
 *
 * This is the template for the content of subscription section
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */
if ( ! function_exists( 'musicsong_pro_add_subscription_section' ) ) :
    /**
    * Add subscription section
    *
    *@since Musicsong Pro 1.0.0
    */
    function musicsong_pro_add_subscription_section() {
    	$options = musicsong_pro_get_theme_options();
        // Check if subscription is enabled on frontpage
        $subscription_enable = apply_filters( 'musicsong_pro_section_status', true, 'subscription_section_enable' );

        if ( true !== $subscription_enable ) {
            return false;
        }

        // Render subscription section now.
        musicsong_pro_render_subscription_section();
    }
endif;
add_action( 'musicsong_pro_content_end_action', 'musicsong_pro_add_subscription_section', 5 );

if ( ! function_exists( 'musicsong_pro_render_subscription_section' ) ) :
  /**
   * Start subscription section
   *
   * @return string subscription content
   * @since Musicsong Pro 1.0.0
   *
   */
   function musicsong_pro_render_subscription_section() {
        $options = musicsong_pro_get_theme_options();
        
        if ( ! class_exists( 'Jetpack' ) ) {
            return;
        } elseif ( class_exists( 'Jetpack' ) ) {
            if ( ! Jetpack::is_module_active( 'subscriptions' ) )
                return;
        }
        ?>

        <div id="subscribe-us" class="relative page-section">
            <div class="wrapper col-2">
                <?php if ( ! empty( $options['subscription_title'] ) || ! empty( $options['subscription_subtitle'] ) ) : ?>
                    <div class="section-header">
                        <?php if ( ! empty( $options['subscription_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['subscription_title'] ); ?></h2>
                        <?php endif; 

                        if ( ! empty( $options['subscription_subtitle'] ) ) : ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['subscription_subtitle'] ); ?></p>
                        <?php endif; ?>
                    </div><!-- .section-header -->
                <?php endif; ?>

                <div class="section-content">
                    <?php  
                        $subscription_shortcode = '[jetpack_subscription_form title="" subscribe_text="" subscribe_button="' . esc_html__( 'Subscribe', 'musicsong-pro' ) . '" show_subscribers_total="0"]';
                        echo do_shortcode( wp_kses_post( $subscription_shortcode ) ); 
                    ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #subscribe-us -->

    <?php }
endif;